@@ -10,7 +10,10 @@ This module provides response filter decorators.
 import gzip as gzip2
 import zlib
 
-import brotli as _brotli
+try:
+    import brotlicffi as _brotli
+except ImportError:
+    import brotli as _brotli
 
 from six import BytesIO
 from decimal import Decimal
